MediaInfo class

Constructors

MediaInfo({required BigInt durationMs, required int width, required int height, required int rotation, required double fps, required String videoCodec, String? audioCodec, required BigInt bitrate, required BigInt fileSize, required bool hasDolbyVision, required bool preferSoftwarePreview})
const

Properties

audioCodec String?
final
bitrate BigInt
final
durationMs BigInt
final
fileSize BigInt
final
fps double
final
hasDolbyVision bool
True for iPhone / camera Dolby Vision HEVC (preview uses software decode on Apple).
final
hashCode int
The hash code for this object.
no setteroverride
height int
final
preferSoftwarePreview bool
When true, UI should use session RGBA decode (skip VideoToolbox seek on Apple).
final
rotation int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoCodec String
final
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override