VideoPreviewSession class abstract

Constructors

VideoPreviewSession()

Properties

hashCode int
The hash code for this object.
no setterinherited
isDisposed bool
Whether the underlying Arc is disposed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

close() → void
dispose() → void
Dispose the underlying Arc.
inherited
nextFramePixelBuffer() Future<PreviewFramePixelBuffer?>
nextFrameRgba() Future<PreviewFrameRgba?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pausePlayback() → void
seekAndDecodePixelBuffer({required BigInt positionMs}) Future<PreviewFramePixelBuffer>
seekAndDecodeRgba({required BigInt positionMs}) Future<PreviewFrameRgba>
setPreviewMaxEdge({int? maxEdge}) → void
Updates preview scale for subsequent decode/scrub/playback frames (no demuxer reopen).
startPlayback({required double rate}) Stream<PlaybackFrame>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

create({required String inputPath, int? maxEdge, required bool preferHw}) VideoPreviewSession