MediaInfo class
Constructors
-
MediaInfo({required BigInt durationMs, required int width, required int height, required int rotation, required double fps, required String videoCodec, String? audioCodec, required BigInt bitrate, required BigInt fileSize, required bool hasDolbyVision, required bool preferSoftwarePreview})
-
const
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited